# UKBiobank-tools


## Requirements

It is highly recommended to install the Anaconda python distribution (Python 3.6) which contains most dependencies (see https://www.anaconda.com/download/).

### About

UKBiobank-tools is a simple application enabling the filtering and pre-processing of ukbiobank datasets.


### Viewing documentation 

https://ukbiobank-tools.readthedocs.io/en/latest/

## Contributing

Feel free to contribute via pull requests
